//+------------------------------------------------------------------+
//|                                             closs-all-profit.mq4 |
//|                             Copyright 2024, Trade Smart FX Tools |
//|                                https://tradesmartfxtools.online/ |
//+------------------------------------------------------------------+
#property copyright "Copyright 2024, Trade Smart FX Tools"
#property link      "https://tradesmartfxtools.online/"
#property version   "1.00"
#property strict

//+------------------------------------------------------------------+
//| Expert initialization function                                   |
//+------------------------------------------------------------------+

string labelName = "tradesmartfxtools.online";
string labelText = "EA by tradesmartfxtools.online";
int labelFontSize = 18;
color labelColor = Yellow;
int spaceFromBottom = 50;

// Additional text for the updated version
string updatedLabelName = "updated_version_label";
string updatedLabelText = "Updated version available at tradesmartfxtools.online";
int updatedLabelFontSize = 12;  // Smaller font size for the updated version text
color updatedLabelColor = White;
int updatedSpaceFromBottom = 20;  // Position it below the main label

void createOrUpdateLabels()
{
    // Create the main label
    if (ObjectFind(0, labelName) == -1)
    {
        ObjectCreate(0, labelName, OBJ_LABEL, 0, 0, 0);
        ObjectSetInteger(0, labelName, OBJPROP_CORNER, CORNER_LEFT_LOWER);
        ObjectSetInteger(0, labelName, OBJPROP_XDISTANCE, 10);
        ObjectSetInteger(0, labelName, OBJPROP_YDISTANCE, spaceFromBottom);
        ObjectSetInteger(0, labelName, OBJPROP_COLOR, labelColor);
        ObjectSetInteger(0, labelName, OBJPROP_FONTSIZE, labelFontSize);
        ObjectSetString(0, labelName, OBJPROP_TEXT, labelText);
    }

    // Create the updated version label below the main label
    if (ObjectFind(0, updatedLabelName) == -1)
    {
        ObjectCreate(0, updatedLabelName, OBJ_LABEL, 0, 0, 0);
        ObjectSetInteger(0, updatedLabelName, OBJPROP_CORNER, CORNER_LEFT_LOWER);
        ObjectSetInteger(0, updatedLabelName, OBJPROP_XDISTANCE, 10);
        ObjectSetInteger(0, updatedLabelName, OBJPROP_YDISTANCE, updatedSpaceFromBottom);
        ObjectSetInteger(0, updatedLabelName, OBJPROP_COLOR, updatedLabelColor);
        ObjectSetInteger(0, updatedLabelName, OBJPROP_FONTSIZE, updatedLabelFontSize);
        ObjectSetString(0, updatedLabelName, OBJPROP_TEXT, updatedLabelText);
    }
}


int OnInit()
  {
   // Create a styled button on the chart (right side)
   CreateStyledButton("btnCloseProfitable", "Close All Profitable Trades", 0, 20, 220, 50);
     createOrUpdateLabels();
   return(INIT_SUCCEEDED);
  }
//+------------------------------------------------------------------+
//| Expert deinitialization function                                 |
//+------------------------------------------------------------------+
void OnDeinit(const int reason)
  {
   // Delete the button when EA is removed
   ObjectDelete("btnCloseProfitable");
  }
//+------------------------------------------------------------------+
//| Chart event handler function                                     |
//+------------------------------------------------------------------+
void OnChartEvent(const int id, const long& lparam, const double& dparam, const string& sparam)
  {
   // Check if the button was clicked
   if (id == CHARTEVENT_OBJECT_CLICK && sparam == "btnCloseProfitable")
     {
      // Close all profitable trades
      CloseProfitableTrades();
      Print("clicked");
     }
  }
//+------------------------------------------------------------------+
//| Function to create a styled button                               |
//+------------------------------------------------------------------+
void CreateStyledButton(string name, string label, int sub_window, int x_distance, int width, int height)
  {
   // Create the button object
   if (!ObjectCreate(0, name, OBJ_BUTTON, sub_window, 0, 0))
     {
      Print("Error creating button ", name);
      return;
     }

   // Set button properties for positioning and appearance
   ObjectSetInteger(0, name, OBJPROP_CORNER, CORNER_LEFT_UPPER);  // Position in the upper-left corner
   ObjectSetInteger(0, name, OBJPROP_XDISTANCE, x_distance);      // X distance from left edge
   ObjectSetInteger(0, name, OBJPROP_YDISTANCE, 20);              // Y distance from top
   ObjectSetInteger(0, name, OBJPROP_XSIZE, width);               // Button width
   ObjectSetInteger(0, name, OBJPROP_YSIZE, height);              // Button height
   ObjectSetString(0, name, OBJPROP_TEXT, label);                 // Button label

   // Set background, text color, and border colors
   ObjectSetInteger(0, name, OBJPROP_BGCOLOR, clrGreen);          // Button background color (green)
   ObjectSetInteger(0, name, OBJPROP_BORDER_TYPE, BORDER_RAISED); // Raised border
   ObjectSetInteger(0, name, OBJPROP_STYLE, STYLE_SOLID);         // Solid border
   ObjectSetInteger(0, name, OBJPROP_COLOR, clrWhite);            // Button text color (white)
   ObjectSetInteger(0, name, OBJPROP_FONTSIZE, 12);               // Font size
  }
//+------------------------------------------------------------------+
//| Function to close all profitable trades                         |
//+------------------------------------------------------------------+
void CloseProfitableTrades()
  {
   int totalOrders = OrdersTotal();
   if(totalOrders == 0)
     {
      Print("No open orders found.");
      return;
     }
   
   for (int i = totalOrders - 1; i >= 0; i--)
     {
      if (OrderSelect(i, SELECT_BY_POS, MODE_TRADES))
        {
         // Check if the trade is profitable
         double profit = OrderProfit();
         if (profit >= 0.00)
           {
            // Attempt to close the order
            bool closed = false;
            if (OrderType() == OP_BUY)
              {
               closed = OrderClose(OrderTicket(), OrderLots(), Bid, 2, clrRed);
               if (closed)
                 Print("Closed profitable Buy order ", OrderTicket(), " with profit: ", profit);
               else
                 Print("Error closing Buy order ", OrderTicket(), ": Error code ", GetLastError());
              }
            else if (OrderType() == OP_SELL)
              {
               closed = OrderClose(OrderTicket(), OrderLots(), Ask, 2, clrRed);
               if (closed)
                 Print("Closed profitable Sell order ", OrderTicket(), " with profit: ", profit);
               else
                 Print("Error closing Sell order ", OrderTicket(), ": Error code ", GetLastError());
              }
           }
         else
           {
            Print("Order ", OrderTicket(), " is not profitable, skipping.");
           }
        }
      else
        {
         Print("Error selecting order ", i, ": Error code ", GetLastError());
        }
     }
  }
//+------------------------------------------------------------------+

